diff --git a/app/javascript/wardrobe-2020/WardrobePage/ItemsPanel.js b/app/javascript/wardrobe-2020/WardrobePage/ItemsPanel.js
index 927f0c38..d84058be 100644
--- a/app/javascript/wardrobe-2020/WardrobePage/ItemsPanel.js
+++ b/app/javascript/wardrobe-2020/WardrobePage/ItemsPanel.js
@@ -279,11 +279,11 @@ function ItemZoneGroupSkeleton({ itemCount }) {
}
/**
* GetTheseItemsButton shows the "Get these items!" button, to link to the
* Shopping List page for the items in this outfit. If there are no items being
* worn, this is disabled.
*/
-function GetTheseItemsButton({ outfitState }) {
+function ShoppingListButton({ outfitState }) {
const [searchParams] = useSearchParams();
const [isVisible, setIsVisible] = useLocalStorage("DTIShowGetTheseItems");
@@ -466,7 +466,7 @@ function OutfitHeading({ outfitState, outfitSaving, dispatchToOutfit }) {
@@ -279,11 +279,11 @@ function ItemZoneGroupSkeleton({ itemCount }) {
}
/**
- * GetTheseItemsButton shows the "Get these items!" button, to link to the
- * Shopping List page for the items in this outfit. If there are no items being
- * worn, this is disabled.
+ * ShoppingListButton shows the "Shopping list" button, to link to the Shopping=
+ * List page for the items in this outfit. If there are no items being worn,
+ * this is disabled.
*/